@@ -3,7 +3,7 @@ from pathlib import Path
 
 from jupyter_ascending.handlers import jupyter_server
 from jupyter_ascending.json_requests import GetStatusRequest
-
+from jupyter_ascending.logger import J_LOGGER
 
 def send(file_name: str):
     file_name = str(Path(file_name).absolute())
@@ -13,6 +13,7 @@ def send(file_name: str):
 
 
 if __name__ == "__main__":
+    J_LOGGER.disable("__main__")
     parser = argparse.ArgumentParser()
 
     parser.add_argument("--filename", help="Filename to send")
